require 'rest-client'
require 'json'

require 'tyntec-ruby/version' unless defined?(Tyntec::VERSION)

require 'tyntec-ruby/util/configuration'
require 'tyntec-ruby/rest/uri_helper'

Dir.glob(File.join(__dir__, 'tyntec-ruby', 'rest', '*.rb')).sort.each(&method(:require))
Dir.glob(File.join(__dir__, 'tyntec-ruby', 'rest', '**', '*.rb')).sort.each(&method(:require))

# Base gem module.
# Allow global configuration
# Example:
# Tyntec.configure do |c|
#   c.api_key = ...
#   c.logger = ...
# end
module Tyntec
  class Error < StandardError; end

  class ClientError < Error; end

  class RequestError < ClientError; end

  extend SingleForwardable

  def_delegators :configuration, :api_key, :logger

  def self.configure
    yield configuration
  end

  def self.configuration
    @configuration ||= Util::Configuration.new
  end

  private_class_method :configuration
end
